==> limny-3.0.0.tar.bz2: limny-3.0.0/admin/login.php <==
<?php

/*
 * login.php
 *
 * @copyright     Copyright 2009-2011 Hamid Reza Samak
 * @link          http://www.limny.org
 * @package       limny
 * @author        Hamid Reza Samak <hamid@limny.org>
 * @license       GNU/GPL License (http://www.gnu.org/licenses/gpl.html)
 */

require('../init.php');
require('../incs/user.class.php');
require('admin.class.php');

session_name('_limny');
session_start();

$class['admin'] = new Admin;

if($class['admin']->is_authorized())
{
	header('Location: index.php');
}else{
	require('../incs/config.class.php');
	require('../incs/language.class.php');
	
	$class['config'] = new Config;
	$class['language'] = new Language;
	require('../langs/' . $class['language']->language . '/admin.php');
	
	if(isset($_POST['limny_user']) && isset($_POST['limny_pass']))
	{
		$user = $_POST['limny_user'];
		$pass = $_POST['limny_pass'];
		
		$class['user'] = new User;
		
		if($class['user']->user_exists($user, $pass))
		{
			if(!$class['user']->is_banned($user))
			{
				if($class['admin']->is_admin($user))
				{
					$remember = (isset($_POST['limny_remember'])) ? true : false;		
					$class['user']->set_login_session($user, $pass, $remember);
					
					header('Location: index.php');
				}else{
					$message = INFO_3;
				}
			}else{
				$message = INFO_2;
			}
		}else{
			$message = INFO_1;
		}
	}else{
		$message = false;
	}
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" dir="<?php print $class['language']->direction; ?>">
<head>
<title><?php print ADMINISTRATION . ' | ' . $class['config']->title; ?></title>
<meta http-equiv="Content-Type" content="text/html; charset=<?php print $class['language']->charset; ?>" />
<meta name="generator" content="Limny <?php print $class['config']->version; ?>" />
<link href="<?php print ($class['language']->direction == 'rtl') ? 'rtl/login-rtl.css' : 'login.css'; ?>" type="text/css" rel="stylesheet" />
<link href="table.css" type="text/css" rel="stylesheet" />
<link rel="shortcut icon" href="<?php print base_path(); ?>/misc/favicon.ico" type="image/x-icon" />
<?php
if(!isset($_POST['limny_user']) && !isset($_POST['limny_pass']))
{
?>
<script type="text/javascript" src="../misc/jquery.js"></script>
<script type="text/javascript">
$(document).ready(function(){
	$("div.login").css("display", "none").fadeIn(1000);
	$("input[type=text]").attr("autocomplete", "off");
});
</script>
<?php
}
?>
</head>
<body>
<div class="login">
	<div class="title"><label><?php print LOGIN_TO_ACCOUNT; ?></label></div>	
	
	<div class="box">
		<?php if($message){ ?>
		<div class="message"><?php print $message; ?>
		<?php } ?>
		<div style="clear:both;"></div>
	</div>
	
	<form name="limny_login" action="<?php print $_SERVER['PHP_SELF']; ?>" method="post">
		<div class="table">
			<div class="row">
				<div class="cell label"><?php print USERNAME; ?>:</div>
				<div class="cell field"><input name="limny_user" type="text" size="20" value="" /></div>
			</div>
			<div class="row">
				<div class="cell label"><?php print PASSWORD; ?>:</div>
				<div class="cell field"><input name="limny_pass" type="password" size="20" value="" /></div>
			</div>
		</div>
		<div>
			<div class="cell remember"><label><input name="limny_remember" type="checkbox" value="1" /> <?php print REMEMBER_ME_ON_THIS_COMPUTER; ?></label></div>
			<div class="cell button"><input name="limny_login" type="submit" value="<?php print LOGIN; ?>" /></div>
		</div>
	</form>
	<div class="footer">
		<div class="links">
			<a href="<?php print url('-/forgot-password', true); ?>" title="<?php print I_CANT_ACCESS_MY_ACCOUNT; ?>"><?php echo I_CANT_ACCESS_MY_ACCOUNT; ?></a><br />
		</div>
		<div class="limny"><br /><?php print POWERED_BY; ?>: <a title="Limny" href="http://www.limny.org">Limny</a></div>
	</div>
</div>
</body>
</html>
<?php
}
?>

==> limny-3.2.1.tar.bz2: limny-3.2.1/admin/login.php <==
<?php

/*
 * login.php
 *
 * @copyright     Copyright 2009-2012 Hamid Reza Samak
 * @link          http://www.limny.org
 * @package       limny
 * @author        Hamid Reza Samak <hamid@limny.org>
 * @license       GNU/GPL License (http://www.gnu.org/licenses/gpl.html)
 */

require('../init.php');
require('../incs/user.class.php');
require('admin.class.php');

session_name('_limny');
session_start();

$class['admin'] = new Admin;

if($class['admin']->is_authorized())
{
	header('Location: index.php');
	exit;
}
else
{
	require('../incs/config.class.php');
	require('../incs/language.class.php');
	
	$class['config'] = new Config;
	$class['language'] = new Language;
	require('../langs/' . $class['language']->language . '/admin.php');
	
	if (isset($_POST['limny_user']) && isset($_POST['limny_pass']))
	{
		$user = $_POST['limny_user'];
		$pass = $_POST['limny_pass'];
		
		$class['user'] = new User;
		
		if ($class['user']->user_exists($user, $pass))
		{
			if (!$class['user']->is_banned($user))
			{
				if ($class['admin']->is_admin($user))
				{
					$remember = (isset($_POST['limny_remember'])) ? TRUE : FALSE;		
					$class['user']->set_login_session($user, $pass, $remember);
					
					header('Location: index.php');
					exit;
				}
				else
				{
					$message = INFO_3;
				}
			}
			else
			{
				$message = INFO_2;
			}
		}
		else
		{
			$message = INFO_1;
		}
	}
	else
	{
		$message = false;
	}
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" dir="<?php print $class['language']->direction; ?>">
<head>
<title><?php print ADMINISTRATION . ' - ' . $class['config']->title; ?></title>
<meta http-equiv="Content-Type" content="text/html; charset=<?php print $class['language']->charset; ?>" />
<meta name="generator" content="Limny <?php print $class['config']->version; ?>" />
<link href="<?php print ($class['language']->direction == 'rtl') ? 'rtl/login-rtl.css' : 'login.css'; ?>" type="text/css" rel="stylesheet" />
<link href="table.css" type="text/css" rel="stylesheet" />
<link rel="shortcut icon" href="<?php print base_path(); ?>/misc/favicon.ico" type="image/x-icon" />
<?php
if (!isset($_POST['limny_user']) && !isset($_POST['limny_pass']))
{
?>
<script type="text/javascript" src="../misc/jquery.js"></script>
<script type="text/javascript">
$(document).ready(function(){
	$("div.login").css("display", "none").fadeIn(1000);
	$("input[type=text]").attr("autocomplete", "off").focus();
});
</script>
<?php
}
?>
</head>
<body>
<div class="login">
	<div class="title"><label><?php print LOGIN_TO_ACCOUNT; ?></label></div>	
	
	<div class="box">
		<?php if ($message) { ?>
		<div class="message"><?php print $message; ?>
		<?php } ?>
		<div style="clear:both;"></div>
	</div>
	
	<form name="limny_login" action="login.php" method="post">
		<div class="table">
			<div class="row">
				<div class="cell label"><?php print USERNAME; ?>:</div>
				<div class="cell field"><input name="limny_user" type="text" size="20" value="" /></div>
			</div>
			<div class="row">
				<div class="cell label"><?php print PASSWORD; ?>:</div>
				<div class="cell field"><input name="limny_pass" type="password" size="20" value="" /></div>
			</div>
		</div>
		<div>
			<div class="cell remember"><label><input name="limny_remember" type="checkbox" value="1" /> <?php print REMEMBER_ME_ON_THIS_COMPUTER; ?></label></div>
			<div class="cell button"><input name="limny_login" type="submit" value="<?php print LOGIN; ?>" /></div>
		</div>
	</form>
	<div class="footer">
		<div class="links">
			<a href="<?php print url('-/forgot-password', true); ?>" title="<?php print I_CANT_ACCESS_MY_ACCOUNT; ?>"><?php echo I_CANT_ACCESS_MY_ACCOUNT; ?></a><br />
		</div>
		<div class="limny"><br /><?php print POWERED_BY; ?>: <a title="Limny" href="http://www.limny.org">Limny</a></div>
	</div>
</div>
</body>
</html>
<?php
}
?>
